@@ -18,12 +18,118 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
-##*******************************************************
-## Functions for calculating confidence intervals for interest measures
-##
-
 # NOTE: prop.test can test differences in proportions (could be used for DOC)
 
+
+#' Confidence Intervals for Interest Measures for Association Rules
+#'
+#' Defines a method to compute confidence intervals for interest measures for association [rules].
+#'
+#' This method creates a contingency table for each rule and then constructs a
+#' confidence interval for the specified measures.
+#'
+#' Fast confidence interval approximations are currently available for the
+#' measures `"support"`, `"count"`, `"confidence"`, `"lift"`, `"oddsRatio"`, and `"phi"`.
+#' For all other measures, bootstrap sampling from a multinomial distribution
+#' is used.
+#'
+#' Haldan-Anscombe correction (Haldan, 1940; Anscombe, 1956) to avoids issues
+#' with zero counts can be specified by `smoothCounts = 0.5`. Here .5 is
+#' added to each count in the contingency table.
+#'
+#' @name confint
+#' @family interest measures
+#' 
+#' @aliases confint confint.rules
+#' @param object an object of class [rules].
+#' @param parm,measure name of the interest measures (see [interestMeasure()]).
+#' `measure` can be used instead of `parm`.
+#' @param level the confidence level required.
+#' @param side Should a two-sided confidence interval or a one-sided limit be
+#' returned? Lower returns an interval with only a lower limit and upper
+#' returns an interval with only an upper limit.
+#' @param method method to construct the confidence interval. The available
+#' methods depends on the measure and the most common method is used by
+#' default.
+#' @param smoothCounts pseudo count for addaptive smoothing (Laplace
+#' smoothing). Often a pseudo counts of .5 is used for smoothing (see Detail
+#' Section).
+#' @param replications number of replications for method `"simulation"`. Ignored
+#' for other methods.
+#' @param transactions if the rules object does not contain sufficient quality
+#' information, then a set of transactions to calculate the confidence interval
+#' for can be specified.
+#' @param ... Additional parameters are ignored with a warning.
+#' @return Returns a matrix with with one row for each rule and the two columns
+#' named `"LL"` and `"UL"` with the interval boundaries.
+#' The matrix has the following additional attributes:
+#'
+#' \item{measure}{ the interest measure.} 
+#' \item{level}{ the confidence level}
+#' \item{side}{ the confidence level} 
+#' \item{smoothCounts}{ used count
+#' smoothing. } 
+#' \item{method}{ name of the method to create the interval }
+#' \item{desc}{ description of the used method to calculate the confidence
+#' interval. The mentioned references can be found below. }
+#' @author Michael Hahsler
+#' @references Wilson, E. B. (1927). "Probable inference, the law of
+#' succession, and statistical inference". 
+#' _Journal of the American Statistical Association,_ 22 (158): 209-212.
+#' \doi{10.1080/01621459.1927.10502953}
+#'
+#' Clopper, C.; Pearson, E. S. (1934). "The use of confidence or fiducial
+#' limits illustrated in the case of the binomial". _Biometrika,_ 26 (4):
+#' 404-413. 
+#' \doi{10.1093/biomet/26.4.404}
+#'
+#' Doob, J. L. (1935). "The Limiting Distributions of Certain Statistics".
+#' _Annals of Mathematical Statistics,_ 6: 160-169.
+#' \doi{10.1214/aoms/1177732594}
+#'
+#' Fisher, R.A. (1962). "Confidence limits for a cross-product ratio".
+#' _Australian Journal of Statistics,_ 4, 41.
+#'
+#' Woolf, B. (1955). "On estimating the relation between blood group and
+#' diseases". _Annals of Human Genetics,_ 19, 251-253.
+#'
+#' Haldane, J.B.S. (1940). "The mean and variance of the moments of chi-squared
+#' when used as a test of homogeneity, when expectations are small".
+#' _Biometrika,_ 29, 133-134.
+#'
+#' Anscombe, F.J. (1956). "On estimating binomial response relations".
+#' _Biometrika,_ 43, 461-464.
+#' @keywords manip
+#' @examples
+#' data("Income")
+#'
+#' # mine some rules with the consequent "language in home=english"
+#' rules <- apriori(Income, parameter = list(support = 0.5),
+#'   appearance = list(rhs = "language in home=english"))
+#'
+#' # calculate the confidence interval for the rules' odds ratios.
+#' # note that we use Haldane-Anscombe correction (with smoothCounts = .5)
+#' # to avoid issues with 0 counts in the contingency table.
+#' ci <- confint(rules, "oddsRatio",  smoothCounts = .5)
+#' ci
+#'
+#' # We add the odds ratio (with Haldane-Anscombe correction)
+#' # and the confidence intervals to the quality slot of the rules.
+#' quality(rules) <- cbind(
+#'   quality(rules),
+#'   oddsRatio = interestMeasure(rules, "oddsRatio", smoothCounts = .5),
+#'   oddsRatio = ci)
+#'
+#' rules <- sort(rules, by = "oddsRatio")
+#' inspect(rules)
+#'
+#' # use confidence intervals for lift to find rules with a lift significantly larger then 1.
+#' # We set the confidence level to 95%, create a one-sided interval and check
+#' # if the interval does not cover 1 (i.e., the lower limit is larger than 1).
+#' ci <- confint(rules, "lift", level = 0.95, side = "lower")
+#' ci
+#'
+#' inspect(rules[ci[, "LL"] > 1])
 confint.rules <- function(object,
   parm = "oddsRatio",
   level = 0.95,
@@ -101,8 +207,8 @@ confint.rules <- function(object,
     qs <- c((1 - level) / 2, (1 + level) / 2)
     
     # smooth for better probability estimates
-    counts <- counts[,c("n11", "n10", "n01", "n00")] + smoothCounts
-    n <- sum(counts[1, ])
+    counts <- counts[, c("n11", "n10", "n01", "n00")] + smoothCounts
+    n <- sum(counts[1,])
     p <- counts / n
     
     ci <-
@@ -113,17 +219,22 @@ confint.rules <- function(object,
         dimnames = list(NULL, c("LL", "UL"))
       )
     
+    se <- vector(length = nrow(p))
+    
     ### simulated counts also need to be smoothed
     for (i in seq(nrow(p))) {
-      ns <- t(stats::rmultinom(replications, n, p[i, ]))
+      ns <- t(stats::rmultinom(replications, n, p[i,]))
       colnames(ns) <- c("n11", "n10", "n01", "n00")
-      vals <- .basicRuleMeasure(ns, measure, smoothCounts = smoothCounts, ...)
+      vals <-
+        .basicRuleMeasure(ns, measure, smoothCounts = smoothCounts, ...)
       if (!any(is.na(vals)))
-        ci[i, ] <- stats::quantile(vals, probs = qs)
+        ci[i,] <- stats::quantile(vals, probs = qs)
+        se[i] <- stats::sd(vals) / sqrt(replications)
     }
     
     structure(
       ci,
+      se = se,
       measure = measure,
       level = level,
       method = method,
@@ -152,6 +263,7 @@ ci.norm <- function(mean,
       UL = mean + z * se)
   
   structure(ci,
+    se = se,
     desc = desc)
 }
 
@@ -196,7 +308,8 @@ ci.prop.binom <-
 .vector_OR <- Vectorize(function(n11, n01, n10, n00, level)
   stats::fisher.test(ceil(rbind(
     c(n11, n01), c(n10, n00)
-  )), conf.level = level)$conf.int,)
+  )), conf.level = level)$conf.int,
+)
 # ceil rounds up in case of a non-integer smoothCounts value
 
 ci.or.exact <-
@@ -255,8 +368,8 @@ ci.or.exact <-
         wilson = ci.prop.wilson(n11, n, level) * n,
         bootstrap = NULL
       )
-    
-    ci[ci < 0] <- 0
+      
+      ci[ci < 0] <- 0
     }
     
     #####################################################
@@ -271,7 +384,7 @@ ci.or.exact <-
         wilson = ci.prop.wilson(n11, n, level),
         bootstrap = NULL
       )
-    
+      
       ci[ci < 0] <- 0
       ci[ci > 1] <- 1
     }
